@@ -1,5 +1,4 @@
 # encoding: utf-8
-import time
 import weakref
 from importlib import import_module
 from pathlib import PurePosixPath
@@ -21,6 +20,9 @@ from .system import System
 from .user import User, Users
 from .view import Views
 
+EMPTY_FOLDER_XML = '''<?xml version='1.0' encoding='UTF-8'?>
+<com.cloudbees.hudson.plugins.folder.Folder/>'''
+
 
 class Jenkins(Item):
     r'''Constructs  :class:`Jenkins <Jenkins>`.
@@ -74,7 +76,8 @@ class Jenkins(Item):
             <FreeStyleProject: http://127.0.0.1:8080/job/freestylejob/>
         '''
         folder, name = self._resolve_name(full_name)
-        return folder.get(name)
+        if folder.exists():
+            return folder.get(name)
 
     def iter_jobs(self, depth=0):
         '''Iterate jobs with depth
@@ -94,11 +97,12 @@ class Jenkins(Item):
         folder = Folder(self, self.url)
         yield from folder.iter(depth)
 
-    def create_job(self, full_name, xml):
+    def create_job(self, full_name, xml, recursive=False):
         '''Create new jenkins job with given xml configuration
 
         :param full_name: ``str``, full name of job
         :param xml: xml configuration string
+        :param recursive: (optional) Boolean, recursively create folder if not existed
 
         Usage::
 
@@ -118,6 +122,8 @@ class Jenkins(Item):
             <FreeStyleProject: http://127.0.0.1:8080/job/freestylejob/>
         '''
         folder, name = self._resolve_name(full_name)
+        if recursive and not folder.exists():
+            self.create_job(folder.full_name, EMPTY_FOLDER_XML, recursive=recursive)
         return folder.create(name, xml)
 
     def copy_job(self, full_name, dest):
@@ -246,9 +252,7 @@ class Jenkins(Item):
         except ConnectionError:
             return False
         except HTTPError as e:
-            if e.response.status_code in [401, 403]:
-                return True
-            return False
+            return e.response.status_code in [401, 403]
 
     @property
     def crumb(self):
@@ -256,12 +260,12 @@ class Jenkins(Item):
         if self._crumb is None:
             try:
                 _crumb = self.send_req(
-                    'GET', self.url + 'crumbIssuer/api/json').json()
+                    'GET', f'{self.url}crumbIssuer/api/json').json()
                 self._crumb = {_crumb['crumbRequestField']: _crumb['crumb']}
             except HTTPError as e:
                 if e.response.status_code in [401, 403]:
                     raise AuthenticationError(
-                        'Invalid authorization for %s' % self) from e
+                        f'Invalid authorization for {self}') from e
                 self._crumb = {}
         return self._crumb
 
